Imported from libpng-1.0.7beta18.tar
diff --git a/png.h b/png.h
index 8e18bf1..d88c026 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.0.7rc1 - June 9, 2000
  * Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.0.7rc1 - June 9, 2000: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -52,8 +52,8 @@
  *    1.0.6h                        10007  10.6h (testing xy.z so-numbering)
  *    1.0.6i                        10007  10.6i
  *    1.0.6j                        10007  2.1.0.6j (incompatible with 1.0.0)
- *    1.0.7beta11-16                10007  2.1.0.7beta11-16 (binary compatible)
- *    1.0.7rc1                      10007  2.1.0.7rc1 (binary compatible)
+ *    1.0.7beta11-18                10007  2.1.0.7beta11-18 (binary compatible)
+ *    1.0.7rc1-2                    10007  2.1.0.7rc1-2 (binary compatible)
  *    planned:
  *    1.0.6patch4 (w/4 patches)     10006  2.1.0.6 (binary compatible)
  *    1.0.7                         10007  (still compatible)
@@ -83,7 +83,7 @@
  * If you modify libpng you may insert additional notices immediately following
  * this sentence.
  *
  * libpng versions 1.0.6, March 20, 2000, through 1.0.7rc1, June 9, 2000, are
  * Copyright (c) 2000 Glenn Randers-Pehrson
  * Distributed according to the same disclaimer and license as libpng-1.0.5
  * with the following individuals added to the list of Contributing Authors:
@@ -179,13 +179,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    June 9, 2000
+ *    June 24, 2000
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.0.7rc1 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -231,8 +231,8 @@
  *       PNG Development Group
  */
 
-#ifndef _PNG_H
-#define _PNG_H
+#ifndef PNG_H
+#define PNG_H
 
 /* This is not the place to learn how to use libpng.  The file libpng.txt
  * describes how to use libpng, and the file example.c summarizes it
@@ -241,7 +241,7 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.7rc1"
+#define PNG_LIBPNG_VER_STRING "1.0.7beta18"
 
 #define PNG_LIBPNG_VER_SONUM   2
 
@@ -251,7 +251,7 @@
 #define PNG_LIBPNG_VER_RELEASE 7
 /* This should match the numeric part of the final component of
  * PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD   1
+#define PNG_LIBPNG_VER_BUILD   18
 
 /* Careful here.  At one time, Guy wanted to use 082, but that would be octal.
  * We must not include leading zeros.
@@ -1140,9 +1140,9 @@
 };
 
 /* This prevents a compiler error in png_get_copyright() in png.c if png.c
-and png.h are both at * version 1.0.7rc1
+and png.h are both at * version 1.0.7beta18
  */
-typedef png_structp version_1_0_7rc1;
+typedef png_structp version_1_0_7beta18;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -2161,7 +2161,7 @@
 extern PNG_EXPORT(png_charp,png_get_libpng_ver) PNGARG((png_structp png_ptr));
 
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.0.7rc1 - June 9, 2000 (header)\n"
+   " libpng version 1.0.7beta18 - June 24, 2000 (header)\n"
 
 #ifdef PNG_READ_COMPOSITE_NODIV_SUPPORTED
 /* With these routines we avoid an integer divide, which will be slower on
@@ -2955,4 +2955,4 @@
 
 #endif /* PNG_VERSION_INFO_ONLY */
 /* do not put anything past this line */
-#endif /* _PNG_H */
+#endif /* PNG_H */
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.0.7rc1 - June 9, 2000
+ * libpng version 1.0.7beta18 - June 24, 2000
  * Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.0.7rc1 - June 9, 2000: Glenn
+ *  libpng versions 0.97, January 1998, through 1.0.7beta18 - June 24, 2000: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -83,7 +83,7 @@
  * this sentence.
  *
- * libpng versions 1.0.6, March 20, 2000, through 1.0.7rc1, June 9, 2000, are
+ * libpng versions 1.0.6, March 20, 2000, through 1.0.7beta18, June 24, 2000, are
  * Copyright (c) 2000 Glenn Randers-Pehrson
  * Distributed according to the same disclaimer and license as libpng-1.0.5
@@ -179,13 +179,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.0.7rc1 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.0.7beta18 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *